@@ -6,6 +6,63 @@ from svgwrite import cm, mm, inch
 
 
 class Gerber:
+    def __init__(self, file, verbose=False):
+        self.verbose = verbose
+        # extracts and sorts a zipped gerber file
+        if(self.verbose):
+            print('Extracting Files')
+        if not os.path.exists('./gerber_files'):
+            os.makedirs('./gerber_files')
+        else:
+            shutil.rmtree('./gerber_files')
+        with zipfile.ZipFile(file, 'r') as zipped:
+            zipped.extractall('./gerber_files')
+
+        drill = ''
+        outline = ''
+        t_copper = ''
+        t_mask = ''
+        t_silk = ''
+        b_copper = ''
+        b_mask = ''
+        b_silk = ''
+
+        # RS274X name schemes
+        for filename in os.listdir('./gerber_files'):
+            if(not drill and filename[-3:].upper() == 'DRL'):
+                drill = './gerber_files/'+filename
+            elif(not outline and filename[-3:].upper() == 'GKO'):
+                outline = './gerber_files/'+filename
+            elif(not t_copper and filename[-3:].upper() == 'GTL'):
+                t_copper = './gerber_files/'+filename
+            elif(not t_mask and filename[-3:].upper() == 'GTS'):
+                t_mask = './gerber_files/'+filename
+            elif(not t_silk and filename[-3:].upper() == 'GTO'):
+                t_silk = './gerber_files/'+filename
+            elif(not b_copper and filename[-3:].upper() == 'GBL'):
+                b_copper = './gerber_files/'+filename
+            elif(not b_mask and filename[-3:].upper() == 'GBS'):
+                b_mask = './gerber_files/'+filename
+            elif(not b_silk and filename[-3:].upper() == 'GBO'):
+                b_silk = './gerber_files/'+filename
+
+        # render top
+        if(drill and outline and t_copper and t_mask):
+            if(self.verbose):
+                print('Rendring Top')
+            self.render_files(outline=outline, drill=drill, copper=t_copper,
+                              mask=t_mask, silk=t_silk, filename='top.svg')
+        else:
+            print('Error identifying files')
+
+        if(drill and outline and b_copper and b_mask):
+            if(self.verbose):
+                print('Rendering Bottom')
+            self.render_files(outline=outline, drill=drill, copper=b_copper,
+                              mask=b_mask, silk=b_silk, filename='bottom.svg')
+        elif(self.verbose):
+            print('No Bottom Files')
+
     def draw_macros(self, file, color, fill='none'):
         index = 0
         # draw circles
@@ -160,8 +217,8 @@ class Gerber:
         # draw copper layer
         if(self.verbose):
             print('Etching Copper')
-        draw_macros(file=copper_file,
-                    color='darkgreen')
+        self.draw_macros(file=copper_file,
+                         color='darkgreen')
 
         # open top solder mask file
         mask_file = open(mask, 'r').read()
@@ -170,8 +227,8 @@ class Gerber:
         if(self.verbose):
             print('Applying Solder Mask')
 
-        area_fill(file=mask_file,  color='grey')
-        draw_macros(file=mask_file,  color='grey')
+        self.area_fill(file=mask_file,  color='grey')
+        self.draw_macros(file=mask_file,  color='grey')
 
         if(silk):
             # open top silk screen file
@@ -181,10 +238,10 @@ class Gerber:
             if(self.verbose):
                 print('Curing Silk Screen')
             # draw silkscreen with macros
-            draw_macros(file=silk_file,
-                        color='white')
-            area_fill(file=silk_file,
-                      color='white')
+            self.draw_macros(file=silk_file,
+                             color='white')
+            self.area_fill(file=silk_file,
+                           color='white')
 
         # open drill file
         drill_file = open(drill, 'r').read()
@@ -231,60 +288,3 @@ class Gerber:
             return [self.width, self.height]
         else:
             return 'Board Not Rendered'
-
-    def __init__(self, file, verbose=False):
-        self.verbose = verbose
-        # extracts and sorts a zipped gerber file
-        if(self.verbose):
-            print('Extracting Files')
-        if not os.path.exists('./gerber_files'):
-            os.makedirs('./gerber_files')
-        else:
-            shutil.rmtree('./gerber_files')
-        with zipfile.ZipFile(file, 'r') as zipped:
-            zipped.extractall('./gerber_files')
-
-        drill = ''
-        outline = ''
-        t_copper = ''
-        t_mask = ''
-        t_silk = ''
-        b_copper = ''
-        b_mask = ''
-        b_silk = ''
-
-        # RS274X name schemes
-        for filename in os.listdir('./gerber_files'):
-            if(not drill and filename[-3:].upper() == 'DRL'):
-                drill = './gerber_files/'+filename
-            elif(not outline and filename[-3:].upper() == 'GKO'):
-                outline = './gerber_files/'+filename
-            elif(not t_copper and filename[-3:].upper() == 'GTL'):
-                t_copper = './gerber_files/'+filename
-            elif(not t_mask and filename[-3:].upper() == 'GTS'):
-                t_mask = './gerber_files/'+filename
-            elif(not t_silk and filename[-3:].upper() == 'GTO'):
-                t_silk = './gerber_files/'+filename
-            elif(not b_copper and filename[-3:].upper() == 'GBL'):
-                b_copper = './gerber_files/'+filename
-            elif(not b_mask and filename[-3:].upper() == 'GBS'):
-                b_mask = './gerber_files/'+filename
-            elif(not b_silk and filename[-3:].upper() == 'GBO'):
-                b_silk = './gerber_files/'+filename
-
-        # render top
-        if(drill and outline and t_copper and t_mask):
-            if(self.verbose):
-                print('Rendring Top')
-            render_files(outline=outline, drill=drill, copper=t_copper,
-                         mask=t_mask, silk=t_silk, filename='top.svg')
-        else:
-            print('Error identifying files')
-
-        if(drill and outline and b_copper and b_mask):
-            if(self.verbose):
-                print('Rendering Bottom')
-            render_files(outline=outline, drill=drill, copper=b_copper,
-                         mask=b_mask, silk=b_silk, filename='bottom.svg')
-        elif(self.verbose):
-            print('No Bottom Files')
